==> haskell-ptr-0.16.8.7-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-14XSuPG0ybAGX0VVo2Uead
key:                  ptr-0.16.8.7-14XSuPG0ybAGX0VVo2Uead
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  542f85666427fd489abef8038984fd24
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-14XSuPG0ybAGX0VVo2Uead
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    profunctors-5.6.3-54dftqYvfC87HlKhU8lZc
    strict-list-0.1.7.6-7tXSfmbPjmlA4yxnWEOGlZ text-2.0.2 time-1.12.2
    vector-0.13.2.0-52P7Ozt5w3I6hi4WvheJB9

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ptr-0.16.8.7-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-GYgsx9sAcnn5mVrNq3UaMa
key:                  ptr-0.16.8.7-GYgsx9sAcnn5mVrNq3UaMa
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  e537ee8e4c23faa583cc2409b50b0838
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-GYgsx9sAcnn5mVrNq3UaMa
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    profunctors-5.6.3-63mQtfUXOTH6K8o94A7vA
    strict-list-0.1.7.6-JgdCDMz74ujAJJUP6XrFuD text-2.0.2 time-1.12.2
    vector-0.13.2.0-K0fBmK5qd7y3388236ZS0A

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
